@@ -1,4 +1,5 @@
 import os
+import click
 
 from flask import Flask
 
@@ -15,3 +16,8 @@ def create_app(test_config=None):
     app.register_blueprint(endpoints.bp)
 
     return app
+
+@click.command()
+def cli():
+    """Example script."""
+    click.echo('Hello World 2!')
\ No newline at end of file
